==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/admin_msg.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

settype($act, "string");
if ($act == "add") {
	$Heading = KWL_PrepareHtml($Heading);
	$Content = trim($Content);
	$expire = mktime($hour,$min,0,$month,$day,$year);
	$sql  = "INSERT INTO T_Admin_Msg (Heading,Content,Active,Expire,Date,Type) ";
	$sql .= "VALUES ('$Heading','$Content',$Active,$expire,".time().",$Type)";
	SqlQuery($sql);

} elseif ($act == "update") {
	if ($Rid) {
      $Heading = KWL_PrepareHtml($Heading);
      $Content = trim($Content);
      $expire = mktime($hour,$min,0,$month,$day,$year);
      $sql  = "UPDATE T_Admin_Msg SET Heading = '$Heading', Content = '$Content', ";
      $sql .= "Active = $Active , Expire = $expire , Type = $Type WHERE Rid = $Rid";
      SqlQuery($sql);
   }

} elseif ($act == "kill") {
	
	if ($id) SqlQuery("DELETE FROM T_Admin_Msg WHERE Rid = $id");
	
} elseif ($act == "edit") {

	$VAR["Heading"] = _ADMIN_MSG_EDIT;
	$VAR["Content"] = make_admin_msg_form("update",$id);
	KWL_DrawMain($VAR);
	
} elseif ($act == "preview") {
	$A = SqlQueryFetchArray("SELECT * FROM T_Admin_Msg WHERE Rid = $id");
	if (!$A['Type']) KWL_ParseContent($A['Content'],3);
	KWL_DrawMain($A);
}

$rt = SqlQuery("SELECT * FROM T_Admin_Msg ORDER BY Rid DESC");
$VAR["Heading"] = _ADMIN_MSG;
$VAR["Content"] = "
<table cellpadding=\"2\" cellspacing=\"1\" width=\"100%\" border=\"1\">
<tr><th>". _PREVIEW ."</th> <th>". _DISPLAY ."</th> <th>". _DISPLAY_TYPE ."</th>
<th>". _EXPIRE ."</th><th>op</th></tr>";

while ($msg = mysql_fetch_array($rt)) {
	if ($msg['Type']) $msg['Type'] = _PARSE_L0;
	else $msg['Type'] = _PARSE_L3;
	if ($msg['Active']) $msg['Active'] = _ACTIVE;
	else $msg['Active'] = _INACTIVE;
	
	$VAR["Content"] .= "<tr>"
		. "<td><a href=\"admin_msg.php?act=preview&amp;id=$msg[Rid]\">$msg[Heading]</A></td><td>$msg[Active]</td><td>$msg[Type]</td>"
		. "<td>". date("Y-m-d H:i",$msg['Expire']) ."</td>"
		. "<td align=\"center\"><A onclick=\"return getconfirm();\" href=\"admin_msg.php?act=kill&amp;id=$msg[Rid]\"><img src=\"$CONF[img_url]/kill.gif\" alt=\"kill\" border=\"0\" /></a>&nbsp;<a href=\"admin_msg.php?act=edit&amp;id=$msg[Rid]\"><img src=\"$CONF[img_url]/edit.gif\" alt=\"edit\" border=\"0\" /></a></td>"
		. "</tr>";
}
$VAR["Content"] .= "</table>";
KWL_DrawMain($VAR);

if ($act != "edit") {
	$VAR["Heading"] = _ADMIN_MSG_ADD;
	$VAR["Content"] = make_admin_msg_form("add");
	KWL_DrawMain($VAR);
}

include("../include/footer.inc.php");

function make_admin_msg_form($act,$id='') {
	global $size,$agent;

	if ($act == "update" && $id) {
		$msg = SqlQueryFetchArray("SELECT * FROM T_Admin_Msg WHERE Rid = $id");
		$year    = date("Y", $msg['Expire']);
		$day     = date("d", $msg['Expire']);
		$month   = date("m", $msg['Expire']);
		$hour    = date("H", $msg['Expire']);
		$min     = date("i", $msg['Expire']);
	} else {
      $carray = array('Heading','Content','Active','Type','Rid');
      foreach ($carray as $k) { $msg[$k] = ""; }
      $year = 0; $day =0; $month=0; $hour=0; $min=0;
   }

   $out = new KWL_Html;
$ret = $out->form_start("admin/admin_msg.php",$act).
       $out->table_start("100%",'',0,0,3).
"<tr>
	<td>". _TITLE .": <br />
   ". $out->input_form("text","Heading",$msg['Heading'],$size['titl'],200) ."
	</td>
</tr>
<tr>
	<td>". _CONTENT .": ". KWL_FormResizer("$act.Content",$size['text'],15) .
   $out->textarea("Content",15,$size['text'],KWL_PrepareHtml($msg['Content'])) ."
	</td>
</tr>
<tr>
	<td>". _DISPLAY .": ". $out->select("Active",array( 0 => _INACTIVE, 
                                                       1 => _ACTIVE ), $msg['Active']) ."
	</td>
</tr>
<tr>
	<td>". _DISPLAY_TYPE .": ". $out->select("Type", array ( 0 => _PARSE_L3,
                                                            1 => _PARSE_L0), $msg['Type']) ."
	</td>
</tr>
<tr>
	<td>". _EXPIRE .": ". KWL_MakeTimeSelect($year,$day,$month,$hour,$min) ."</td>
</tr>
<tr>
	<td>". $out->input_form("hidden","act",$act) .
          $out->input_form("hidden","Rid",$msg['Rid']) .
          $out->input_form("submit",'',_SAVE_CHANGE) ."
	</td></tr>". $out->table_end() . $out->form_end();
return $ret;
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/admin_msg.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

settype($act, "string");
if ($act == "add") {
	$Heading = KWL_PrepareHtml($Heading);
	$Content = trim($Content);
	$expire = mktime($hour,$min,0,$month,$day,$year);
	$sql  = "INSERT INTO T_Admin_Msg (Heading,Content,Active,Expire,Date,Type) ";
	$sql .= "VALUES ('$Heading','$Content',$Active,$expire,".time().",$Type)";
	SqlQuery($sql);

} elseif ($act == "update") {
	if ($Rid) {
      $Heading = KWL_PrepareHtml($Heading);
      $Content = trim($Content);
      $expire = mktime($hour,$min,0,$month,$day,$year);
      $sql  = "UPDATE T_Admin_Msg SET Heading = '$Heading', Content = '$Content', ";
      $sql .= "Active = $Active , Expire = $expire , Type = $Type WHERE Rid = $Rid";
      SqlQuery($sql);
   }

} elseif ($act == "kill") {
	
	if ($id) SqlQuery("DELETE FROM T_Admin_Msg WHERE Rid = $id");
	
} elseif ($act == "edit") {

	$VAR["Heading"] = _ADMIN_MSG_EDIT;
	$VAR["Content"] = make_admin_msg_form("update",$id);
	KWL_DrawMain($VAR);
	
} elseif ($act == "preview") {
	$A = SqlQueryFetchArray("SELECT * FROM T_Admin_Msg WHERE Rid = $id");
	if (!$A['Type']) KWL_ParseContent($A['Content'],3);
	KWL_DrawMain($A);
}

$rt = SqlQuery("SELECT * FROM T_Admin_Msg ORDER BY Rid DESC");
$VAR["Heading"] = _ADMIN_MSG;
$VAR["Content"] = "
<table cellpadding=\"2\" cellspacing=\"1\" width=\"100%\" border=\"1\">
<tr><th>". _PREVIEW ."</th> <th>". _DISPLAY ."</th> <th>". _DISPLAY_TYPE ."</th>
<th>". _EXPIRE ."</th><th>OP</th></tr>";

while ($msg = mysql_fetch_array($rt)) {
	if ($msg['Type']) $msg['Type'] = _PARSE_L0;
	else $msg['Type'] = _PARSE_L3;
	if ($msg['Active']) $msg['Active'] = _ACTIVE;
	else $msg['Active'] = _INACTIVE;
	
	$VAR["Content"] .= "<tr>"
		. "<td><a href=\"admin_msg.php?act=preview&amp;id=$msg[Rid]\">$msg[Heading]</A></td><td>$msg[Active]</td><td>$msg[Type]</td>"
		. "<td>". date("Y-m-d H:i",$msg['Expire']) ."</td>"
		. "<td align=\"center\"><A onclick=\"return getconfirm();\" href=\"admin_msg.php?act=kill&amp;id=$msg[Rid]\"><img src=\"$CONF[img_url]/kill.gif\" alt=\"kill\" border=\"0\" /></a>&nbsp;<a href=\"admin_msg.php?act=edit&amp;id=$msg[Rid]\"><img src=\"$CONF[img_url]/edit.gif\" alt=\"edit\" border=\"0\" /></a></td>"
		. "</tr>";
}
$VAR["Content"] .= "</table>";
KWL_DrawMain($VAR);

if ($act != "edit") {
	$VAR["Heading"] = _ADMIN_MSG_ADD;
	$VAR["Content"] = make_admin_msg_form("add");
	KWL_DrawMain($VAR);
}

include("../include/footer.inc.php");

function make_admin_msg_form($act,$id='') {
	global $size,$agent;

	if ($act == "update" && $id) {
		$msg = SqlQueryFetchArray("SELECT * FROM T_Admin_Msg WHERE Rid = $id");
		$year    = date("Y", $msg['Expire']);
		$day     = date("d", $msg['Expire']);
		$month   = date("m", $msg['Expire']);
		$hour    = date("H", $msg['Expire']);
		$min     = date("i", $msg['Expire']);
	} else {
      $carray = array('Heading','Content','Active','Type','Rid');
      foreach ($carray as $k) { $msg[$k] = ""; }
      $year = 0; $day =0; $month=0; $hour=0; $min=0;
   }

   $out = new KWL_Html;
$ret = $out->form_start("admin/admin_msg.php",$act).
       $out->table_start("100%",'',0,0,3).
"<tr>
	<td>". _TITLE .": <br />
   ". $out->input_form("text","Heading",$msg['Heading'],$size['titl'],200) ."
	</td>
</tr>
<tr>
	<td>". _CONTENT .": ". KWL_FormResizer("$act.Content",$size['text'],15) .
   $out->textarea("Content",15,$size['text'],KWL_PrepareHtml($msg['Content'])) ."
	</td>
</tr>
<tr>
	<td>". _DISPLAY .": ". $out->select("Active",array( 0 => _INACTIVE, 
                                                       1 => _ACTIVE ), $msg['Active']) ."
	</td>
</tr>
<tr>
	<td>". _DISPLAY_TYPE .": ". $out->select("Type", array ( 0 => _PARSE_L3,
                                                            1 => _PARSE_L0), $msg['Type']) ."
	</td>
</tr>
<tr>
	<td>". _EXPIRE .": ". KWL_MakeTimeSelect($year,$day,$month,$hour,$min) ."</td>
</tr>
<tr>
	<td>". $out->input_form("hidden","act",$act) .
          $out->input_form("hidden","Rid",$msg['Rid']) .
          $out->input_form("submit",'',_SAVE_CHANGE) ."
	</td></tr>". $out->table_end() . $out->form_end();
return $ret;
}
?>
